==> oil-0.18.0.tar.gz: _devbuild/gen/help_meta.py <==
TOPICS = {'ARGV': 'special-var',
 'Better-Syntax': 'builtin-func',
 'Bool': 'data-lang',
 'Call-Stack': 'special-var',
 'Completion': 'special-var',
 'Dict-aka-object': 'data-lang',
 'Float-aka-number': 'data-lang',
 'Functions': 'special-var',
 'Int': 'data-lang',
 'List-aka-array': 'data-lang',
 'Null': 'data-lang',
 'OIL_VERSION': 'special-var',
 'Oil-Paths': 'special-var',
 'Oil-Special': 'special-var',
 'Other-Env': 'special-var',
 'Other-Special': 'special-var',
 'POSIX-Special': 'special-var',
 'PS1': 'plugin',
 'PS2': 'plugin',
 'PS3': 'plugin',
 'PS4': 'plugin',
 'Platform': 'special-var',
 'Process-Stack': 'special-var',
 'Process-State': 'special-var',
 'SHX_indent': 'special-var',
 'SHX_pid_str': 'special-var',
 'SHX_punct': 'special-var',
 'Shell-Options': 'special-var',
 'Shell-State': 'special-var',
 'Special': 'special-var',
 'Str': 'data-lang',
 'Tracing': 'special-var',
 '_DIALECT': 'special-var',
 '_end()': 'builtin-func',
 '_match()': 'builtin-func',
 '_pipeline_status': 'special-var',
 '_process_sub_status': 'special-var',
 '_start()': 'builtin-func',
 '_status': 'special-var',
 '_this_dir': 'special-var',
 'abs()': 'builtin-func',
 'alias': 'builtin-cmd',
 'all()': 'builtin-func',
 'ampersand': 'cmd-lang',
 'and': 'cmd-lang',
 'any()': 'builtin-func',
 'append': 'builtin-cmd',
 'arith-context': 'mini-lang',
 'arith-sub': 'word-lang',
 'bad-byte': 'data-lang',
 'bad-code-point': 'data-lang',
 'bang': 'cmd-lang',
 'block-arg': 'cmd-lang',
 'block-literal': 'expr-lang',
 'bool()': 'builtin-func',
 'bool-expr': 'mini-lang',
 'bool-infix': 'mini-lang',
 'bool-literal': 'expr-lang',
 'bool-other': 'mini-lang',
 'bool-path': 'mini-lang',
 'bool-str': 'mini-lang',
 'boolstatus': 'builtin-cmd',
 'braces': 'mini-lang',
 'break': 'cmd-lang',
 'builtin': 'builtin-cmd',
 'case': 'cmd-lang',
 'cat-em': 'front-end',
 'cd': 'builtin-cmd',
 'char-escapes': 'mini-lang',
 'chr()': 'builtin-func',
 'class-literal': 'expr-lang',
 'colon': 'cmd-lang',
 'column-attrs': 'data-lang',
 'column-types': 'data-lang',
 'com-sub': 'word-lang',
 'command': 'builtin-cmd',
 'command_sub_errexit': 'option',
 'comment': 'front-end',
 'compadjust': 'builtin-cmd',
 'compexport': 'builtin-cmd',
 'compgen': 'builtin-cmd',
 'complete': 'builtin-cmd',
 'compopt': 'builtin-cmd',
 'concat': 'expr-lang',
 'config': 'front-end',
 'const': 'expr-lang',
 'continue': 'cmd-lang',
 'copy_env': 'option',
 'countRunes()': 'builtin-func',
 'dashglob': 'option',
 'dbracket': 'mini-lang',
 'declare': 'osh-assign',
 'dict()': 'builtin-func',
 'dict-literal': 'expr-lang',
 'dirs': 'builtin-cmd',
 'doc-comment': 'front-end',
 'dparen': 'cmd-lang',
 'echo': 'builtin-cmd',
 'enable': 'builtin-cmd',
 'equal': 'cmd-lang',
 'eval': 'builtin-cmd',
 'exec': 'builtin-cmd',
 'exit': 'cmd-lang',
 'exit-codes': 'front-end',
 'expected-cont': 'data-lang',
 'expected-start': 'data-lang',
 'export': 'osh-assign',
 'expr-lit': 'expr-lang',
 'expr-splice': 'word-lang',
 'expr-sub': 'word-lang',
 'extglob': 'mini-lang',
 'false': 'cmd-lang',
 'fg': 'builtin-cmd',
 'find()': 'builtin-func',
 'float()': 'builtin-func',
 'for': 'cmd-lang',
 'for-expr-sh': 'cmd-lang',
 'fork': 'builtin-cmd',
 'forkwait': 'builtin-cmd',
 'fromStr': 'type-method',
 'func-call': 'expr-lang',
 'getopts': 'builtin-cmd',
 'glob': 'mini-lang',
 'hash': 'builtin-cmd',
 'help': None,
 'here-doc': 'cmd-lang',
 'history': 'builtin-cmd',
 'histsub': 'mini-lang',
 'if': 'cmd-lang',
 'incomplete-seq': 'data-lang',
 'int()': 'builtin-func',
 'int-literal': 'expr-lang',
 'is-main': 'builtin-cmd',
 'j-prefix-j""': 'data-lang',
 'j8-escape': 'data-lang',
 'j8-str': 'word-lang',
 'jobs': 'builtin-cmd',
 'join()': 'builtin-func',
 'json': 'builtin-cmd',
 'json-escape': 'data-lang',
 'kill': 'builtin-cmd',
 'len()': 'builtin-func',
 'line-continuation': 'front-end',
 'list()': 'builtin-func',
 'list-literal': 'expr-lang',
 'local': 'osh-assign',
 'match-ops': 'expr-lang',
 'max()': 'builtin-func',
 'maybe': 'builtin-func',
 'min()': 'builtin-func',
 'module': 'builtin-cmd',
 'multi-str': 'word-lang',
 'multiline-command': 'front-end',
 'named-class': 'expr-lang',
 'nullglob': 'option',
 'oils-usage': None,
 'op-format': 'word-lang',
 'op-index': 'word-lang',
 'op-replace': 'word-lang',
 'op-slice': 'word-lang',
 'op-strip': 'word-lang',
 'op-test': 'word-lang',
 'or': 'cmd-lang',
 'ord()': 'builtin-func',
 'osh-chapters': None,
 'osh-usage': None,
 'overlong': 'data-lang',
 'parse_at': 'option',
 'parse_brace': 'option',
 'parse_equals': 'option',
 'parse_ignored': 'option',
 'parse_paren': 'option',
 'parse_raw_string': 'option',
 'pipe': 'cmd-lang',
 'popd': 'builtin-cmd',
 'pp': 'builtin-cmd',
 'printf': 'builtin-cmd',
 'proc': 'cmd-lang',
 'process_sub_fail': 'option',
 'push-registers': 'builtin-cmd',
 'pushd': 'builtin-cmd',
 'pwd': 'builtin-cmd',
 'quotes': 'word-lang',
 're-compound': 'expr-lang',
 're-flags': 'expr-lang',
 're-literal': 'expr-lang',
 're-multiline': 'expr-lang',
 're-primitive': 'expr-lang',
 'read': 'builtin-cmd',
 'readarray': 'builtin-cmd',
 'redir-desc': 'cmd-lang',
 'redir-file': 'cmd-lang',
 'regex': 'mini-lang',
 'return': 'cmd-lang',
 'round()': 'builtin-func',
 'rune-literal': 'expr-lang',
 'runproc': 'builtin-cmd',
 'semicolon': 'cmd-lang',
 'set': 'builtin-cmd',
 'setglobal': 'expr-lang',
 'setref': 'expr-lang',
 'setvar': 'expr-lang',
 'sh-append': 'osh-assign',
 'sh-arith': 'mini-lang',
 'sh-array': 'osh-assign',
 'sh-assign': 'osh-assign',
 'sh-assoc': 'osh-assign',
 'sh-bitwise': 'mini-lang',
 'sh-block': 'cmd-lang',
 'sh-func': 'cmd-lang',
 'sh-logical': 'mini-lang',
 'sh-numbers': 'mini-lang',
 'shift': 'osh-assign',
 'shopt': 'builtin-cmd',
 'shvar': 'builtin-cmd',
 'shvar_get()': 'builtin-func',
 'sigpipe_status_ok': 'option',
 'simple-command': 'cmd-lang',
 'simple_word_eval': 'option',
 'source': 'builtin-cmd',
 'split()': 'builtin-func',
 'startup': 'front-end',
 'str()': 'builtin-func',
 'str-literal': 'expr-lang',
 'strict:all': 'option',
 'strict_control_flow': 'option',
 'strict_nameref': 'option',
 'strict_tilde': 'option',
 'strict_word_eval': 'option',
 'sub()': 'builtin-func',
 'subshell': 'cmd-lang',
 'sum()': 'builtin-func',
 'surrogate-pair': 'data-lang',
 'test': 'builtin-cmd',
 'tilde-sub': 'word-lang',
 'time': 'cmd-lang',
 'times': 'builtin-cmd',
 'toJ8': 'type-method',
 'trap': 'builtin-cmd',
 'true': 'cmd-lang',
 'try': 'builtin-cmd',
 'type': 'builtin-cmd',
 'type()': 'builtin-func',
 'typed-arg': 'cmd-lang',
 'typeset': 'osh-assign',
 'umask': 'builtin-cmd',
 'unalias': 'builtin-cmd',
 'underscore': 'cmd-lang',
 'unset': 'osh-assign',
 'until': 'cmd-lang',
 'use': 'builtin-cmd',
 'var': 'expr-lang',
 'var-splice': 'word-lang',
 'var-sub': 'word-lang',
 'wait': 'builtin-cmd',
 'while': 'cmd-lang',
 'write': 'builtin-cmd',
 'ysh-arith': 'expr-lang',
 'ysh-bitwise': 'expr-lang',
 'ysh-case': 'cmd-lang',
 'ysh-cd': 'builtin-cmd',
 'ysh-chapters': None,
 'ysh-compare': 'expr-lang',
 'ysh-for': 'cmd-lang',
 'ysh-format': 'word-lang',
 'ysh-if': 'cmd-lang',
 'ysh-index': 'expr-lang',
 'ysh-logical': 'expr-lang',
 'ysh-printf': 'word-lang',
 'ysh-read': 'builtin-cmd',
 'ysh-shopt': 'builtin-cmd',
 'ysh-slice': 'expr-lang',
 'ysh-ternary': 'expr-lang',
 'ysh-usage': None,
 'ysh-while': 'cmd-lang',
 'ysh:all': 'option',
 'ysh:upgrade': 'option'}


from typing import Dict

def TopicMetadata():
  # type: () -> Dict[str, str]
  return TOPICS

==> oil-0.19.0.tar.gz: _devbuild/gen/help_meta.py <==
TOPICS = {'ARGV': 'special-var',
 'Better-Syntax': 'builtin-func',
 'Bool': 'data-lang',
 'Call-Stack': 'special-var',
 'Completion': 'special-var',
 'Dict-aka-object': 'data-lang',
 'Float-aka-number': 'data-lang',
 'Functions': 'special-var',
 'Int': 'data-lang',
 'List-aka-array': 'data-lang',
 'Null': 'data-lang',
 'OIL_VERSION': 'special-var',
 'Oil-Paths': 'special-var',
 'Oil-Special': 'special-var',
 'Other-Env': 'special-var',
 'Other-Special': 'special-var',
 'POSIX-Special': 'special-var',
 'PS1': 'plugin',
 'PS2': 'plugin',
 'PS3': 'plugin',
 'PS4': 'plugin',
 'Platform': 'special-var',
 'Process-Stack': 'special-var',
 'Process-State': 'special-var',
 'SHX_indent': 'special-var',
 'SHX_pid_str': 'special-var',
 'SHX_punct': 'special-var',
 'Shell-Options': 'special-var',
 'Shell-State': 'special-var',
 'Special': 'special-var',
 'Str': 'data-lang',
 'Tracing': 'special-var',
 '_DIALECT': 'special-var',
 '_end()': 'builtin-func',
 '_match()': 'builtin-func',
 '_pipeline_status': 'special-var',
 '_process_sub_status': 'special-var',
 '_start()': 'builtin-func',
 '_status': 'special-var',
 '_this_dir': 'special-var',
 'abs()': 'builtin-func',
 'accum()': 'type-method',
 'alias': 'builtin-cmd',
 'all()': 'builtin-func',
 'ampersand': 'cmd-lang',
 'and': 'cmd-lang',
 'any()': 'builtin-func',
 'append': 'builtin-cmd',
 'append()': 'type-method',
 'arith-context': 'mini-lang',
 'arith-sub': 'word-lang',
 'bad-byte': 'data-lang',
 'bad-code-point': 'data-lang',
 'bang': 'cmd-lang',
 'block-arg': 'cmd-lang',
 'block-literal': 'expr-lang',
 'bool()': 'builtin-func',
 'bool-expr': 'mini-lang',
 'bool-infix': 'mini-lang',
 'bool-literal': 'expr-lang',
 'bool-other': 'mini-lang',
 'bool-path': 'mini-lang',
 'bool-str': 'mini-lang',
 'boolstatus': 'builtin-cmd',
 'braces': 'mini-lang',
 'break': 'cmd-lang',
 'builtin': 'builtin-cmd',
 'call': 'cmd-lang',
 'captureStdout()': 'type-method',
 'case': 'cmd-lang',
 'cat-em': 'front-end',
 'cd': 'builtin-cmd',
 'char-escapes': 'mini-lang',
 'chr()': 'builtin-func',
 'class-literal': 'expr-lang',
 'colon': 'cmd-lang',
 'column-attrs': 'data-lang',
 'column-types': 'data-lang',
 'com-sub': 'word-lang',
 'command': 'builtin-cmd',
 'command_sub_errexit': 'option',
 'comment': 'front-end',
 'compadjust': 'builtin-cmd',
 'compexport': 'builtin-cmd',
 'compgen': 'builtin-cmd',
 'complete': 'builtin-cmd',
 'compopt': 'builtin-cmd',
 'concat': 'expr-lang',
 'config': 'front-end',
 'const': 'expr-lang',
 'continue': 'cmd-lang',
 'copy_env': 'option',
 'countRunes()': 'builtin-func',
 'dashglob': 'option',
 'dbracket': 'mini-lang',
 'declare': 'osh-assign',
 'dict()': 'builtin-func',
 'dict-literal': 'expr-lang',
 'dirs': 'builtin-cmd',
 'doc-comment': 'front-end',
 'dparen': 'cmd-lang',
 'echo': 'builtin-cmd',
 'enable': 'builtin-cmd',
 'endsWith()': 'type-method',
 'equal': 'cmd-lang',
 'erase()': 'type-method',
 'error': 'builtin-cmd',
 'eval': 'builtin-cmd',
 'eval()': 'type-method',
 'exec': 'builtin-cmd',
 'exit': 'cmd-lang',
 'exit-codes': 'front-end',
 'expected-cont': 'data-lang',
 'expected-start': 'data-lang',
 'export': 'osh-assign',
 'expr-lit': 'expr-lang',
 'expr-splice': 'word-lang',
 'expr-sub': 'word-lang',
 'extend()': 'type-method',
 'extglob': 'mini-lang',
 'false': 'cmd-lang',
 'fat-arrow': 'expr-lang',
 'fg': 'builtin-cmd',
 'find()': 'type-method',
 'float()': 'builtin-func',
 'for': 'cmd-lang',
 'for-expr-sh': 'cmd-lang',
 'fork': 'builtin-cmd',
 'forkwait': 'builtin-cmd',
 'func-call': 'expr-lang',
 'get()': 'type-method',
 'getopts': 'builtin-cmd',
 'glob': 'mini-lang',
 'glob()': 'type-method',
 'hash': 'builtin-cmd',
 'help': None,
 'here-doc': 'cmd-lang',
 'history': 'builtin-cmd',
 'histsub': 'mini-lang',
 'if': 'cmd-lang',
 'inc()': 'type-method',
 'incomplete-seq': 'data-lang',
 'insert()': 'type-method',
 'int()': 'builtin-func',
 'int-literal': 'expr-lang',
 'is-main': 'builtin-cmd',
 'j-prefix-j""': 'data-lang',
 'j8-escape': 'data-lang',
 'j8-str': 'word-lang',
 'jobs': 'builtin-cmd',
 'join()': 'builtin-func',
 'json': 'builtin-cmd',
 'json-escape': 'data-lang',
 'keys()': 'type-method',
 'kill': 'builtin-cmd',
 'lazy-expr-arg': 'cmd-lang',
 'len()': 'builtin-func',
 'line-continuation': 'front-end',
 'list()': 'builtin-func',
 'list-literal': 'expr-lang',
 'local': 'osh-assign',
 'lower()': 'type-method',
 'match-ops': 'expr-lang',
 'max()': 'builtin-func',
 'maybe': 'builtin-func',
 'min()': 'builtin-func',
 'module': 'builtin-cmd',
 'multi-str': 'word-lang',
 'multiline-command': 'front-end',
 'named-class': 'expr-lang',
 'nullglob': 'option',
 'oils-usage': None,
 'op-format': 'word-lang',
 'op-index': 'word-lang',
 'op-replace': 'word-lang',
 'op-slice': 'word-lang',
 'op-strip': 'word-lang',
 'op-test': 'word-lang',
 'or': 'cmd-lang',
 'ord()': 'builtin-func',
 'osh-chapters': None,
 'osh-usage': None,
 'overlong': 'data-lang',
 'parse_at': 'option',
 'parse_brace': 'option',
 'parse_equals': 'option',
 'parse_ignored': 'option',
 'parse_paren': 'option',
 'parse_raw_string': 'option',
 'pipe': 'cmd-lang',
 'pop()': 'type-method',
 'popd': 'builtin-cmd',
 'pp': 'builtin-cmd',
 'printf': 'builtin-cmd',
 'proc': 'cmd-lang',
 'process_sub_fail': 'option',
 'promptVal()': 'type-method',
 'push-registers': 'builtin-cmd',
 'pushd': 'builtin-cmd',
 'pwd': 'builtin-cmd',
 'quotes': 'word-lang',
 'range': 'expr-lang',
 're-compound': 'expr-lang',
 're-flags': 'expr-lang',
 're-literal': 'expr-lang',
 're-multiline': 'expr-lang',
 're-primitive': 'expr-lang',
 'read': 'builtin-cmd',
 'readarray': 'builtin-cmd',
 'redir-desc': 'cmd-lang',
 'redir-file': 'cmd-lang',
 'regex': 'mini-lang',
 'remove()': 'type-method',
 'renderPrompt()': 'plugin',
 'replace()': 'type-method',
 'return': 'cmd-lang',
 'reverse()': 'type-method',
 'round()': 'builtin-func',
 'rune-literal': 'expr-lang',
 'runes()': 'builtin-func',
 'runproc': 'builtin-cmd',
 'semicolon': 'cmd-lang',
 'set': 'builtin-cmd',
 'setValue()': 'type-method',
 'setglobal': 'expr-lang',
 'setvar': 'expr-lang',
 'sh-append': 'osh-assign',
 'sh-arith': 'mini-lang',
 'sh-array': 'osh-assign',
 'sh-assign': 'osh-assign',
 'sh-assoc': 'osh-assign',
 'sh-bitwise': 'mini-lang',
 'sh-block': 'cmd-lang',
 'sh-func': 'cmd-lang',
 'sh-logical': 'mini-lang',
 'sh-numbers': 'mini-lang',
 'shSplit()': 'builtin-func',
 'shift': 'osh-assign',
 'shopt': 'builtin-cmd',
 'shvar': 'builtin-cmd',
 'shvar_get()': 'builtin-func',
 'sigpipe_status_ok': 'option',
 'simple-command': 'cmd-lang',
 'simple_word_eval': 'option',
 'source': 'builtin-cmd',
 'split()': 'builtin-func',
 'startsWith()': 'type-method',
 'startup': 'front-end',
 'str()': 'builtin-func',
 'str-literal': 'expr-lang',
 'strftime()': 'type-method',
 'strict:all': 'option',
 'strict_control_flow': 'option',
 'strict_nameref': 'option',
 'strict_tilde': 'option',
 'strict_word_eval': 'option',
 'sub()': 'builtin-func',
 'subshell': 'cmd-lang',
 'sum()': 'builtin-func',
 'surrogate-pair': 'data-lang',
 'test': 'builtin-cmd',
 'thin-arrow': 'expr-lang',
 'tilde-sub': 'word-lang',
 'time': 'cmd-lang',
 'time()': 'type-method',
 'times': 'builtin-cmd',
 'trap': 'builtin-cmd',
 'trim()': 'type-method',
 'trimLeft()': 'type-method',
 'trimPrefix()': 'type-method',
 'trimRight()': 'type-method',
 'trimSuffix()': 'type-method',
 'true': 'cmd-lang',
 'try': 'builtin-cmd',
 'type': 'builtin-cmd',
 'type()': 'builtin-func',
 'typed-arg': 'cmd-lang',
 'typeset': 'osh-assign',
 'umask': 'builtin-cmd',
 'unalias': 'builtin-cmd',
 'unset': 'osh-assign',
 'until': 'cmd-lang',
 'upper()': 'type-method',
 'use': 'builtin-cmd',
 'values()': 'type-method',
 'var': 'expr-lang',
 'var-splice': 'word-lang',
 'var-sub': 'word-lang',
 'wait': 'builtin-cmd',
 'while': 'cmd-lang',
 'write': 'builtin-cmd',
 'ysh-arith': 'expr-lang',
 'ysh-bitwise': 'expr-lang',
 'ysh-case': 'cmd-lang',
 'ysh-cd': 'builtin-cmd',
 'ysh-chapters': None,
 'ysh-compare': 'expr-lang',
 'ysh-for': 'cmd-lang',
 'ysh-format': 'word-lang',
 'ysh-if': 'cmd-lang',
 'ysh-index': 'expr-lang',
 'ysh-logical': 'expr-lang',
 'ysh-printf': 'word-lang',
 'ysh-read': 'builtin-cmd',
 'ysh-shopt': 'builtin-cmd',
 'ysh-slice': 'expr-lang',
 'ysh-ternary': 'expr-lang',
 'ysh-usage': None,
 'ysh-while': 'cmd-lang',
 'ysh:all': 'option',
 'ysh:upgrade': 'option'}


from typing import Dict

def TopicMetadata():
  # type: () -> Dict[str, str]
  return TOPICS
